.. default-intersphinx:: django4.2 djblets5.x python3


===========================
Djblets 5.0.1 Release Notes
===========================

**Release date**: June 7, 2024


Installation
============

To install Djblets 5.0.1, run:

.. code-block:: console

   $ pip3 install Djblets==5.0.1


To learn more, see:

* `Documentation <https://www.reviewboard.org/docs/djblets/5.x/>`_
* `Djblets on PyPI <https://pypi.org/project/Djblets/>`_
* `Djblets on GitHub <https://github.com/djblets/djblets/>`_


.. _Django: https://www.djangoproject.com/


djblets.configforms
===================

* Fixed a regression in clicking actions on table items.

  Action handlers for items weren't being registered correctly for table
  items in a list. This meant that, while the actions were showing up,
  clicking them didn't do anything.


djblets.extensions
==================

* Fixed enabling and disabling extensions in the administration UI.

  The buttons for enabling and disabling extensions were showing up, but
  weren't doing anything when clicked. This was due to the action registration
  issue.


Contributors
============

* Christian Hammond
* David Trowbridge
* Michelle Aubin
